@@ -30,9 +30,9 @@ class regression:
     params()
     significance_of_parameters(0.05)
     fisher(0.05)
-    betta(self)
-    delta(self)
-    elastic(self)
+    betta()
+    delta()
+    elastic()
     predict(pd.DataFrame([[1,1,2],[1,2,2]], columns = ['const','x1','x2']), 'x1')
     breuschpagan()
     Goldfeld_Qandt()
@@ -53,7 +53,7 @@ class regression:
 
   def significance_of_parameters(self, a):
     """|t_calc| < t_tabl not significant"""
-    print('t_tabl:', t.ppf(1-a, self.n-self.k-1))
+    print('t_tabl:', t.ppf(1-a/2, self.n-self.k-1))
     print('t_calc:\n', self.model.tvalues)
     
 
@@ -70,27 +70,27 @@ If F_calc > F_tabl, then Н0 rejected"""
     print('R_adj = ',self.model.rsquared_adj)
     print('Average relative approximation errors = ', sum(abs(((self.model.predict(self.df_x_b)-self.df_y)/self.df_y)))/(self.n))
 
-  def predict(self, X, col):
+  def predict(self, X, col, a):
     """pd.DataFrame([[1,1,2],[1,2,2]], columns = ['const','x1','x2']), 'x1' """
     P = self.model.predict(X)
     print('y = ', P)
   
-    Se_2 = np.var(results.predict(sm.add_constant(X))-y, ddof = 1)**0.5     
+    Se_2 = np.var(self.model.predict(self.df_x_b)-self.df_y, ddof = 1)**0.5     
     X = X[col]
-    min_ = P-Se * t.ppf(1-0.05, self.n-self.k-1) * (1 + 1/self.n + (X-self.df_x.mean())**2/(sum((self.df_x-self.df_x.mean()**2))) )**0.5
-    max_ = P[0]+Se * t.ppf(1-0.05, self.n-self.k-1) * (1 + 1/self.n + (X-self.df_x.mean())**2/(sum((self.df_x-self.df_x.mean()**2))) )**0.5
+    min_ = P-Se * t.ppf(1-a/2, self.n-self.k-1) * (1 + 1/self.n + (X-self.df_x.mean())**2/(sum((self.df_x-self.df_x.mean()**2))) )**0.5
+    max_ = P[0]+Se * t.ppf(1-a/2, self.n-self.k-1) * (1 + 1/self.n + (X-self.df_x.mean())**2/(sum((self.df_x-self.df_x.mean()**2))) )**0.5
     print('Confidence interval Y:\n from', min_, '\n to', max_)
 
   def breuschpagan(self):
     """If p_value > a homoscedasticity"""
     names = ['Lagrange multiplier statistic', 'p-value','f-value', 'f p-value']
     test = sms.het_breuschpagan(self.model.resid, self.model.model.exog)
-    print(lzip(names, test)[1])
+    print(lzip(names, test))
   
   def Goldfeld_Qandt(self):
     """If p_value > a homoscedasticity"""
     test = sm.stats.diagnostic.het_goldfeldquandt(self.df_y, self.df_x_b, drop=0.2)
-    print('p_value -', test[1])
+    print(test)
 
   def spearmen(self, col):
     """if p_value > a homoscedasticity"""
